#!/www/python/bin/python

__revision__ = "$Id: test_basics.py,v 1.6 2002/08/09 21:33:13 gward Exp $"

from optik import OptionParser, OptionGroup, make_option, OptionValueError, \
     SUPPRESS_USAGE
from optik.option_parser import _match_abbrev

options = [make_option("-a", type="string"),
           make_option("-b", "--boo", type="int", dest='boo'),
           make_option("--foo", action="append"),
          ]

parser = OptionParser(usage=SUPPRESS_USAGE, option_list=options)

args = []
(values, args) = parser.parse_args(args)
assert values.a is None
assert values.boo is None
assert values.foo is None
assert len(vars(values)) == 3
assert args == []
print "ok: 1"

defaults = parser.get_default_values()
assert vars(defaults) == vars(values)
print "ok: 2"

args = ["-a"]
try:
    (values, args) = parser.parse_args(args)
except SystemExit, err:
    assert err.args[0].endswith("-a option requires a value"), err.args[0]
    print "ok: 3"
else:
    print "not ok"

(values, args) = parser.parse_args(["-a", "", "--foo=blah", "--foo="])
assert vars(values) == {'a': "",
                        'boo': None,
                        'foo': ["blah", ""]}, vars(values)
assert args == []
print "ok: 4"

(values, args) = parser.parse_args(["--foo", "bar", "--foo", "", "--foo=x"])
assert vars(values) == {'a': None,
                        'boo': None,
                        'foo': ["bar", "", "x"]}, vars(values)
assert args == []
print "ok: 5"

args = ["-abc"]
(values, args) = parser.parse_args(args)
assert vars(values) == {'a': "bc",
                        'boo': None,
                        'foo': None}, vars(values)
assert args == []
print "ok: 6"

args = ["-a", "34"]
(values, args) = parser.parse_args(args)
assert vars(values) == {'a': "34",
                        'boo': None,
                        'foo': None}, vars(values)
assert args == []
print "ok: 7"

args = ["-b34"]
(values, args) = parser.parse_args(args)
assert vars(values) == {'a': None,
                        'boo': 34,
                        'foo': None}, vars(values)
assert args == []
print "ok: 8"

args = ["-b", "-5"]
(values, args) = parser.parse_args(args)
assert vars(values) == {'a': None,
                        'boo': -5,
                        'foo': None}, vars(values)
assert args == []
print "ok: 9"

args = ["-b", "5x"]
try:
    (values, args) = parser.parse_args(args)
except SystemExit, err:
    assert err.args[0].endswith("option -b: invalid integer value: '5x'"), \
           err.args[0]
    print "ok: 10"
else:
    print "not ok"

(values, args) = parser.parse_args(["--boo=13"])
assert vars(values) == {'a': None,
                        'boo': 13,
                        'foo': None}
assert args == []
print "ok: 11"

(values, args) = parser.parse_args(["--boo", "111"])
assert vars(values) == {'a': None,
                        'boo': 111,
                        'foo': None}
assert args == []
print "ok: 12"

try:
    (values, args) = parser.parse_args(["--boo13"])
except SystemExit, err:
    assert err.args[0].endswith("no such option: --boo13"), err.args[0]
    print "ok: 13"
else:
    print "not ok"

try:
    (values, args) = parser.parse_args(["--boo=x5"])
except SystemExit, err:
    assert err.args[0].endswith("option --boo: invalid integer value: 'x5'"), \
           err.args[0]
    print "ok: 14"
else:
    print "not ok"

(values, args) = parser.parse_args(["--foo=bar", "-axyz"])
assert values.foo == ["bar"]
assert values.a == "xyz"
assert values.boo is None
assert args == []
print "ok: 15"

(values, args) = parser.parse_args(["--f=bar", "-axyz"])
assert values.foo == ["bar"]
assert values.a == "xyz"
assert values.boo is None
assert args == []
print "ok: 16"

parser.add_option("--foz", action="store", type="string", dest="foo")
try:
    parser.parse_args(["--f=bar"])
except SystemExit, err:
    assert err.args[0].find("ambiguous option: --f (") != -1,\
           err.args[0]
    print "ok: 17"
else:
    print "not ok"

(values, args) = parser.parse_args(["-a", "xyz", "--foo", "bar"])
assert values.foo == ["bar"]
assert values.a == "xyz"
assert values.boo is None
assert args == []
print "ok: 18"

(values, args) = parser.parse_args(["--foo=bar", "-b", "123", "--foo", "baz"])
assert values.foo == ["bar", "baz"]
assert values.a == None
assert values.boo == 123, `values.boo`
assert args == []
print "ok: 19"

(values, args) = parser.parse_args(["-a", "foo", "bar"])
assert vars(values) == {'a': "foo",
                        'boo': None,
                        'foo': None}
assert args == ["bar"]
print "ok: 20"


(values, args) = parser.parse_args(["-a", "--", "foo", "bar"])
assert vars(values) == {'a': "--",
                        'boo': None,
                        'foo': None}
assert args == ["foo", "bar"]
print "ok: 21"

(values, args) = parser.parse_args(["-ab", "--", "--foo", "bar"])
assert vars(values) == {'a': "b",
                        'boo': None,
                        'foo': None}
assert args == ["--foo", "bar"], args
print "ok: 22"

(values, args) = parser.parse_args(["-ab", "-", "--foo", "bar"])
assert vars(values) == {'a': "b",
                        'boo': None,
                        'foo': ["bar"]}
assert args == ["-"]
print "ok: 23"

args = ["-b3", "-b", "5", "--foo=bar", "--foo", "baz"]
(values, args) = parser.parse_args(args)
assert vars(values) == {'a': None,
                        'boo': 5,
                        'foo': ["bar", "baz"]}
assert args == []
print "ok: 24"

(values, args) = parser.parse_args(["-a", "-b3"])
assert vars(values) == {'a': "-b3",
                        'boo': None,
                        'foo': None}
assert args == []
print "ok: 25"

try:
    _match_abbrev("--f", {"--foz": None, "--foo": None, "--fie": None})
except Exception, err:
    assert str(err).find("ambiguous option: --f (") != -1,\
           str(err)
    print "ok: 26"
else:
    print "not ok"

assert _match_abbrev("--f", {"--foz": None, "--foo": None, "--fie": None,
                             "--f": None}) == "--f"
print "ok: 27"

group = OptionGroup(parser, "Group 1")
parser.add_option_group(group)
group.add_option("--spam", action="store_true", help="spam spam spam spam")
(values, args) = parser.parse_args(["--spam"])
assert vars(values) == {'a': None,
                        'boo': None,
                        'foo': None,
                        'spam': 1}
print "ok: 28"

group = parser.add_option_group("Group 2", description="Some more options")
group.add_option("--bacon", type="int")
(values, args) = parser.parse_args(["--spam", "--bacon=37"])
assert vars(values) == {'a': None,
                        'boo': None,
                        'foo': None,
                        'spam': 1,
                        'bacon': 37}
print "ok: 29"



